@@ -791,6 +791,21 @@ class Builder(Update):
 
         return decor
 
+    def repair_gentoo_repo(self, dct, chroot):
+        from portage.package.ebuild.config import config
+        gentoo_paths = [f'{chroot}/var/db/repos/gentoo', f'{chroot}/usr/portage']
+        try:
+            c = config()
+            if 'gentoo' in c.repositories and 'gentoo' not in dct:
+                for dir_path in gentoo_paths:
+                    if path.exists(dir_path):
+                        dct['gentoo'] = dir_path
+                        break
+        except:
+            pass
+        finally:
+            return dct
+
     def get_rebuild_changed_packages(self, builder_path, repository_data):
         """
         Получить пакеты ebuild которых изменились
@@ -804,6 +819,7 @@ class Builder(Update):
         var_db_path = path.join(builder_path, 'var/db/pkg')
         map_rep = {k: pathJoin(builder_path, v)
                    for k, v in repository_data}
+        map_rep = self.repair_gentoo_repo(map_rep, builder_path)
 
         def rebuild_generator():
             for pkg in InstalledPackageInfo.get_install_packages(var_db_path):
