@@ -119,6 +119,10 @@ class ClBuilderImageAction(Action):
          'method': 'Builder.remove_video_drivers(cl_builder_path)',
          'condition': lambda Get: Get('cl_builder_videodrv_set') == 'off'
          },
+        {'name': 'remove_machine_id',
+         'essential': False,
+         'method': 'Builder.remove_machine_id(cl_builder_path)'
+         },
         {'name': 'trim_reps',
          'foreach': 'cl_builder_sync_rep',
          'message': __("Cleaning the history of the {eachvar:capitalize} "
